aboutsummaryrefslogtreecommitdiff
path: root/src/runtime/mgc.go
diff options
context:
space:
mode:
authorMichael Anthony Knyszek <mknyszek@google.com>2020-07-24 19:58:31 +0000
committerMichael Knyszek <mknyszek@google.com>2020-10-26 17:26:48 +0000
commitc8638498008f9874dc5a48734418e0fbea08cee9 (patch)
treed1d4cc55b139dcc01affc9b8889d386abef09bae /src/runtime/mgc.go
parentd677899e903c4741920846f1af2c14c56f6e710e (diff)
downloadgo-c8638498008f9874dc5a48734418e0fbea08cee9.tar.gz
go-c8638498008f9874dc5a48734418e0fbea08cee9.zip
runtime: rename mcache fields to match Go style
This change renames a bunch of malloc statistics stored in the mcache that are all named with the "local_" prefix. It also renames largeAlloc to allocLarge to prevent a naming conflict, and next_sample because it would be the last mcache field with the old C naming style. Change-Id: I29695cb83b397a435ede7e9ad5c3c9be72767ea3 Reviewed-on: https://go-review.googlesource.com/c/go/+/246969 Trust: Michael Knyszek <mknyszek@google.com> Run-TryBot: Michael Knyszek <mknyszek@google.com> TryBot-Result: Go Bot <gobot@golang.org> Reviewed-by: Michael Pratt <mpratt@google.com>
Diffstat (limited to 'src/runtime/mgc.go')
-rw-r--r--src/runtime/mgc.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/runtime/mgc.go b/src/runtime/mgc.go
index 55554c117c..540c376f1c 100644
--- a/src/runtime/mgc.go
+++ b/src/runtime/mgc.go
@@ -2086,16 +2086,16 @@ func gcMark(start_time int64) {
// Update the marked heap stat.
memstats.heap_marked = work.bytesMarked
// Flush local_scan from each mcache since we're about to modify
// heap_scan directly. If we were to flush this later, then local_scan
// might have incorrect information.
for _, p := range allp {
c := p.mcache
if c == nil {
continue
}
- memstats.heap_scan += uint64(c.local_scan)
- c.local_scan = 0
+ memstats.heap_scan += uint64(c.scanAlloc)
+ c.scanAlloc = 0
}
// Update other GC heap size stats. This must happen after
@@ -2086,16 +2086,16 @@ func gcMark(start_time int64) {
// Update the marked heap stat.
memstats.heap_marked = work.bytesMarked
- // Flush local_scan from each mcache since we're about to modify
- // heap_scan directly. If we were to flush this later, then local_scan
+ // Flush scanAlloc from each mcache since we're about to modify
+ // heap_scan directly. If we were to flush this later, then scanAlloc
// might have incorrect information.
for _, p := range allp {